@@ -18,21 +18,22 @@ EMMTraffic
 
 
 ###################################################
-### code chunk number 3: rEMM.Rnw:863-866
+### code chunk number 3: rEMM.Rnw:863-867
 ###################################################
 emm <- EMM(threshold=0.2, measure="eJaccard")
 build(emm, EMMTraffic)
 size(emm)
+ntransitions(emm)
 
 
 ###################################################
-### code chunk number 4: rEMM.Rnw:876-877
+### code chunk number 4: rEMM.Rnw:877-878
 ###################################################
 cluster_counts(emm)
 
 
 ###################################################
-### code chunk number 5: rEMM.Rnw:882-883
+### code chunk number 5: rEMM.Rnw:883-884
 ###################################################
 cluster_centers(emm)
 
@@ -44,32 +45,32 @@ plot(emm, method="graph")
 
 
 ###################################################
-### code chunk number 7: rEMM.Rnw:914-915
+### code chunk number 7: rEMM.Rnw:915-916
 ###################################################
 transition_matrix(emm)
 
 
 ###################################################
-### code chunk number 8: rEMM.Rnw:919-921
+### code chunk number 8: rEMM.Rnw:920-922
 ###################################################
 transition_matrix(emm, type="counts")
 #transition_matrix(emm, type="log_odds")
 
 
 ###################################################
-### code chunk number 9: rEMM.Rnw:933-934
+### code chunk number 9: rEMM.Rnw:934-935
 ###################################################
 transition(emm, "2", "1", type="probability")
 
 
 ###################################################
-### code chunk number 10: rEMM.Rnw:941-942
+### code chunk number 10: rEMM.Rnw:942-943
 ###################################################
 predict(emm, n=2, current="2")
 
 
 ###################################################
-### code chunk number 11: rEMM.Rnw:947-948
+### code chunk number 11: rEMM.Rnw:948-949
 ###################################################
 predict(emm, n=2, current="2", probabilities=TRUE)
 
@@ -112,7 +113,7 @@ plot(emm_fading_pruned, method="graph")
 
 
 ###################################################
-### code chunk number 17: rEMM.Rnw:1105-1106
+### code chunk number 17: rEMM.Rnw:1106-1107
 ###################################################
 data("EMMsim")
 
@@ -153,41 +154,51 @@ plot(emm, method = "MDS", data=EMMsim_train)
 
 
 ###################################################
-### code chunk number 23: rEMM.Rnw:1301-1303
+### code chunk number 23: simil
 ###################################################
-score(emm, EMMsim_test, method="product", match_cluster="exact")
-score(emm, EMMsim_test, method="sum", match_cluster="exact")
+x <- seq(0,5, length.out=50)
+plot(x, rEMM:::.simil_weight(x,1), type="l", xlab="d(x,s)/t", ylab="simil(x,s)")
 
 
 ###################################################
-### code chunk number 24: rEMM.Rnw:1318-1319
+### code chunk number 24: rEMM.Rnw:1342-1347
 ###################################################
-transition_table(emm, EMMsim_test, match_cluster="exact")
+score(emm, EMMsim_test, method="log_loss")
+score(emm, EMMsim_test, method="likelihood")
+score(emm, EMMsim_test, method="product")
+score(emm, EMMsim_test, method="sum")
+score(emm, EMMsim_test, method="supported_transitions")
 
 
 ###################################################
-### code chunk number 25: rEMM.Rnw:1336-1337
+### code chunk number 25: rEMM.Rnw:1362-1363
 ###################################################
-score(emm, EMMsim_test, method="supported_transitions", match_cluster="exact")
+transition_table(emm, EMMsim_test)
 
 
 ###################################################
-### code chunk number 26: rEMM.Rnw:1346-1347
+### code chunk number 26: rEMM.Rnw:1382-1384
 ###################################################
-score(emm, EMMsim_test, method="supported_transitions", match_cluster="nn")
+score(emm, EMMsim_test, method="product", match_cluster="nn")
+score(emm, EMMsim_test, method="product", match_cluster="weighted")
 
 
 ###################################################
-### code chunk number 27: rEMM.Rnw:1365-1369
+### code chunk number 27: rEMM.Rnw:1397-1398
 ###################################################
-methods <- c("product", "weighted_product", "log_sum", 
-    "weighted_log_sum","sum", "weighted_sum")
+score(emm, EMMsim_test, method="supported_transitions", match_cluster=1.1)
+
+
+###################################################
+### code chunk number 28: rEMM.Rnw:1413-1416
+###################################################
+methods <- c("product", "sum", "log_loss", "likelihood")
 sapply(methods, FUN = function(m) 
-    score(emm, EMMsim_test, method=m, plus_one=TRUE))
+    score(emm, EMMsim_test, method=m, match="weighted"))
 
 
 ###################################################
-### code chunk number 28: sim_hc
+### code chunk number 29: sim_hc
 ###################################################
 ## find best predicting model (clustering)
 k <- 2:10
@@ -196,58 +207,58 @@ plot(attr(emmc, "cluster_info")$dendrogram)
 
 
 ###################################################
-### code chunk number 29: rEMM.Rnw:1406-1409
+### code chunk number 30: rEMM.Rnw:1453-1456
 ###################################################
-sc <- sapply(emmc, score, EMMsim_test, "product")
+sc <- sapply(emmc, score, EMMsim_test, "log_likelihood")
 names(sc) <- k
 sc
 
 
 ###################################################
-### code chunk number 30: sim_optc_graph
+### code chunk number 31: sim_optc_graph
 ###################################################
 plot(emmc[[which.max(sc)]], method="MDS")
 
 
 ###################################################
-### code chunk number 31: sim_optc_MDS
+### code chunk number 32: sim_optc_MDS
 ###################################################
 plot(emmc[[which.max(sc)]], method="MDS", data=EMMsim_train)
 
 
 ###################################################
-### code chunk number 32: rEMM.Rnw:1460-1462
+### code chunk number 33: rEMM.Rnw:1508-1510
 ###################################################
 data(Derwent)
 summary(Derwent)
 
 
 ###################################################
-### code chunk number 33: Derwent1
+### code chunk number 34: Derwent1
 ###################################################
 plot(Derwent[,1], type="l", ylab="Gauged flow", 
 main=colnames(Derwent)[1])
 
 
 ###################################################
-### code chunk number 34: Derwent_cluster_counts
+### code chunk number 35: Derwent_cluster_counts
 ###################################################
 Derwent_scaled <- scale(Derwent)
 emm <- EMM(measure="euclidean", threshold=3)
 build(emm, Derwent_scaled)
-#cluster_counts(emm)
-#state_centers(emm)
+cluster_counts(emm)
+cluster_centers(emm)
 plot(emm, method = "cluster_counts", log="y")
 
 
 ###################################################
-### code chunk number 35: Derwent_EMM1
+### code chunk number 36: Derwent_EMM1
 ###################################################
 plot(emm, method="MDS")
 
 
 ###################################################
-### code chunk number 36: Derwent_EMM2
+### code chunk number 37: Derwent_EMM2
 ###################################################
 rare_threshold <- sum(cluster_counts(emm))*0.005
 rare_threshold
@@ -255,7 +266,7 @@ plot(prune(emm, rare_threshold), method="MDS")
 
 
 ###################################################
-### code chunk number 37: Derwent2
+### code chunk number 38: Derwent2
 ###################################################
 catchment <- 1 
 plot(Derwent[,catchment], type="l", ylab="Gauged flows", 
@@ -270,12 +281,10 @@ mark_states <- function(states, state_sequence, ys, col=0, label=NULL, ...) {
 
 mark_states("11", state_sequence, Derwent[,catchment], col="blue", label="11")
 mark_states("12", state_sequence, Derwent[,catchment], col="red", label="12")
-#mark_states("9", state_sequence, Derwent[,catchment], col="green", label="9")
-#mark_states("3", state_sequence, Derwent[,catchment], col="blue")
 
 
 ###################################################
-### code chunk number 38: Derwent3
+### code chunk number 39: Derwent3
 ###################################################
 catchment <- 6 
 plot(Derwent[,catchment], type="l", ylab="Gauged flow", 
@@ -283,12 +292,10 @@ main=colnames(Derwent)[catchment])
 
 mark_states("11", state_sequence, Derwent[,catchment], col="blue", label="11")
 mark_states("12", state_sequence, Derwent[,catchment], col="red", label="12")
-#mark_states("9", state_sequence, Derwent[,catchment], col="green", label="9")
-#mark_states("3", state_sequence, Derwent[,catchment], col="blue")
 
 
 ###################################################
-### code chunk number 39: rEMM.Rnw:1702-1706
+### code chunk number 40: rEMM.Rnw:1746-1750
 ###################################################
 data("16S")
 
@@ -297,7 +304,7 @@ build(emm, Mollicutes16S+1)
 
 
 ###################################################
-### code chunk number 40: Mollicutes_graph
+### code chunk number 41: Mollicutes_graph
 ###################################################
 plot(emm, method = "graph")
 ## start state for sequences have an initial state probability >0
